@@ -1,6 +1,6 @@
 /* CLI Definitions for GDB, the GNU debugger.
 
-   Copyright (C) 2016-2022 Free Software Foundation, Inc.
+   Copyright (C) 2016-2026 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef CLI_CLI_INTERP_H
-#define CLI_CLI_INTERP_H
+#ifndef GDB_CLI_CLI_INTERP_H
+#define GDB_CLI_CLI_INTERP_H
 
 #include "interps.h"
 
@@ -33,6 +33,15 @@ public:
   void pre_command_loop () override;
   bool supports_command_editing () override;
 
+  void on_signal_received (gdb_signal sig) override;
+  void on_signal_exited (gdb_signal sig) override;
+  void on_normal_stop (bpstat *bs, int print_frame) override;
+  void on_exited (int status) override;
+  void on_no_history () override;
+  void on_sync_execution_done () override;
+  void on_command_error () override;
+  void on_user_selected_context_changed (user_selected_what selection) override;
+
 private:
   struct saved_output_files
   {
@@ -41,7 +50,6 @@ private:
     ui_file *err;
     ui_file *log;
     ui_file *targ;
-    ui_file *targerr;
     /* When redirecting, some or all of these may be non-null
        depending on the logging mode.  */
     ui_file_up stdout_holder;
@@ -60,4 +68,4 @@ private:
 extern int should_print_stop_to_console (struct interp *interp,
 					 struct thread_info *tp);
 
-#endif /* CLI_CLI_INTERP_H */
+#endif /* GDB_CLI_CLI_INTERP_H */
