@@ -1,6 +1,6 @@
 /* GDB routines for manipulating objfiles.
 
-   Copyright (C) 1992-2025 Free Software Foundation, Inc.
+   Copyright (C) 1992-2026 Free Software Foundation, Inc.
 
    Contributed by Cygnus Support, using pieces from other GDB modules.
 
@@ -476,16 +476,6 @@ objfile::~objfile ()
   breakpoint_free_objfile (this);
   btrace_free_objfile (this);
 
-  /* First do any symbol file specific actions required when we are
-     finished with a particular symbol file.  Note that if the objfile
-     is using reusable symbol information (via mmalloc) then each of
-     these routines is responsible for doing the correct thing, either
-     freeing things which are valid only during this particular gdb
-     execution, or leaving them to be reused during the next one.  */
-
-  if (sf != NULL)
-    (*sf->sym_finish) (this);
-
   /* Before the symbol table code was redone to make it easier to
      selectively load and remove information particular to a specific
      linkage unit, gdb used to do these things whenever the monolithic
@@ -1084,14 +1074,28 @@ is_addr_in_objfile (CORE_ADDR addr, const struct objfile *objfile)
   if (objfile == NULL)
     return false;
 
-  for (obj_section &osect : objfile->sections ())
+  if (objfile->sections_start == nullptr)
     {
-      if (section_is_overlay (&osect) && !section_is_mapped (&osect))
-	continue;
-
-      if (osect.contains (addr))
-	return true;
+      /* Objfiles created dynamically by the JIT reader API (and possibly by
+	 other means too) do not have sections.  For such "dynamic" objfiles
+	 walk over all compunits and check if any of them contains given
+	 ADDR.  */
+      for (const compunit_symtab &cu : objfile->compunits ())
+	if (cu.contains (addr))
+	  return true;
     }
+  else
+    {
+      for (obj_section &osect : objfile->sections ())
+	{
+	  if (section_is_overlay (&osect) && !section_is_mapped (&osect))
+	    continue;
+
+	  if (osect.contains (addr))
+	    return true;
+	}
+    }
+
   return false;
 }
 
